==> FreePastry-1.4.1_01_20050816-source.zip: pastry-1.4.1_01_20050816/src/rice/environment/processing/simple/SimpleProcessor.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
/*
 *  Created on Aug 9, 2005
 */
package rice.environment.processing.simple;

import rice.*;
import rice.environment.logging.LogManager;
import rice.environment.processing.Processor;
import rice.environment.time.TimeSource;
import rice.selector.SelectorManager;

/**
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author Jeff Hoye
 */
public class SimpleProcessor implements Processor {
  // the queue used for processing requests
  private ProcessingQueue QUEUE = new ProcessingQueue();
  private ProcessingThread THREAD = new ProcessingThread(QUEUE);

  /**
   * Constructor for SimpleProcessor.
   *
   * @param name DESCRIBE THE PARAMETER
   */
  public SimpleProcessor(String name) {
    THREAD.start();
    THREAD.setPriority(Thread.MIN_PRIORITY);
  }


  /**
   * Gets the Queue attribute of the SimpleProcessor object
   *
   * @return The Queue value
   */
  public ProcessingQueue getQueue() {
    return QUEUE;
  }

  /**
   * Schedules a job for processing on the dedicated processing thread. CPU
   * intensive jobs, such as encryption, erasure encoding, or bloom filter
   * creation should never be done in the context of the underlying node's
   * thread, and should only be done via this method.
   *
   * @param task The task to run on the processing thread
   * @param command The command to return the result to once it's done
   * @param selector DESCRIBE THE PARAMETER
   * @param ts DESCRIBE THE PARAMETER
   * @param log DESCRIBE THE PARAMETER
   */
  public void process(Executable task, Continuation command, SelectorManager selector, TimeSource ts, LogManager log) {
    QUEUE.enqueue(new ProcessingRequest(task, command, log, ts, selector));
  }

  /**
   * DESCRIBE THE METHOD
   */
  public void destroy() {
    THREAD.destroy();
    QUEUE.destroy();
  }
}

==> FreePastry-1.4.1_01_20050914-source.zip: pastry-1.4.1_01_20050914/src/rice/environment/processing/simple/SimpleProcessor.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
/*
 *  Created on Aug 9, 2005
 */
package rice.environment.processing.simple;

import rice.*;
import rice.environment.logging.LogManager;
import rice.environment.processing.*;
import rice.environment.processing.Processor;
import rice.environment.time.TimeSource;
import rice.selector.SelectorManager;

/**
 * @version $Id: pretty.settings,v 1.3 2005/03/11 20:22:33 jeffh Exp $
 * @author Jeff Hoye
 */
public class SimpleProcessor implements Processor {
  // the queue used for processing requests
  private ProcessingQueue QUEUE;
  private ProcessingThread THREAD;

  // for blocking IO WorkRequests
  private WorkQueue workQueue;
  private BlockingIOThread bioThread;

  /**
   * Constructor for SimpleProcessor.
   *
   * @param name DESCRIBE THE PARAMETER
   */
  public SimpleProcessor(String name) {
    QUEUE = new ProcessingQueue();
    THREAD = new ProcessingThread(name + ".ProcessingThread", QUEUE);
    THREAD.start();
    THREAD.setPriority(Thread.MIN_PRIORITY);
    workQueue = new WorkQueue();
    bioThread = new BlockingIOThread(workQueue);
    bioThread.start();
  }


  /**
   * Gets the Queue attribute of the SimpleProcessor object
   *
   * @return The Queue value
   */
  public ProcessingQueue getQueue() {
    return QUEUE;
  }

  /**
   * Gets the IOQueue attribute of the SimpleProcessor object
   *
   * @return The IOQueue value
   */
  public WorkQueue getIOQueue() {
    return workQueue;
  }

  /**
   * Schedules a job for processing on the dedicated processing thread. CPU
   * intensive jobs, such as encryption, erasure encoding, or bloom filter
   * creation should never be done in the context of the underlying node's
   * thread, and should only be done via this method.
   *
   * @param task The task to run on the processing thread
   * @param command The command to return the result to once it's done
   * @param selector DESCRIBE THE PARAMETER
   * @param ts DESCRIBE THE PARAMETER
   * @param log DESCRIBE THE PARAMETER
   */
  public void process(Executable task, Continuation command, SelectorManager selector, TimeSource ts, LogManager log) {
    QUEUE.enqueue(new ProcessingRequest(task, command, log, ts, selector));
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @param workRequest DESCRIBE THE PARAMETER
   */
  public void processBlockingIO(WorkRequest workRequest) {
    workQueue.enqueue(workRequest);
  }

  /**
   * DESCRIBE THE METHOD
   */
  public void destroy() {
    THREAD.destroy();
    QUEUE.destroy();
    bioThread.destroy();
    workQueue.destroy();
  }
}
